@@ -207,10 +207,17 @@ font_infos_loaded (GObject *source_object,
                    gpointer user_data)
 {
     FontViewModel *self = FONT_VIEW_MODEL (source_object);
-    g_autoptr (GPtrArray) items =
-        g_task_propagate_pointer (G_TASK (result), NULL);
+    g_autoptr (GPtrArray) items = NULL;
+    g_autoptr (GError) err = NULL;
 
-    g_list_store_splice (self->model, 0, 0, items->pdata, items->len);
+    items = g_task_propagate_pointer (G_TASK (result), &err);
+
+    if (err == NULL)
+        g_list_store_splice (self->model, 0, 0, items->pdata, items->len);
+    else if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+        g_debug ("Loading fonts canceled");
+    else
+        g_warning ("Could not load font infos: %s", err->message);
 }
 
 static const gchar *
@@ -294,6 +301,19 @@ slant_to_name (int slant)
     return NULL;
 }
 
+static const PangoStyle
+fc_slant_to_pango_style (int slant)
+{
+    switch (slant) {
+    case FC_SLANT_ITALIC:
+        return PANGO_STYLE_ITALIC;
+    case FC_SLANT_OBLIQUE:
+        return PANGO_STYLE_OBLIQUE;
+    }
+
+    return PANGO_STYLE_NORMAL;
+}
+
 static gchar *
 build_font_name (const char *style_name,
                  const char *family_name,
@@ -388,8 +408,8 @@ load_font_infos (GTask *task,
         pango_font_description_set_family (font_description, family_name);
         pango_font_description_set_weight (font_description,
                                            fc_weight_to_pango_weight (weight));
-        // TODO: Support italics
-        pango_font_description_set_style (font_description, PANGO_STYLE_NORMAL);
+        pango_font_description_set_style (font_description,
+                                          fc_slant_to_pango_style (slant));
 
         item = font_view_model_item_new (font_name, font_preview_text,
                                          font_description, file, index);
@@ -530,4 +550,3 @@ font_view_model_get_list_model (FontViewModel *self)
 {
     return G_LIST_MODEL (self->model);
 }
-
