@@ -69,7 +69,7 @@ struct _FontViewWindow
   GtkScrolledWindow *swin_info;
   SushiFontWidget *font_widget;
 
-  AdwMessageDialog *error_dialog;
+  AdwAlertDialog *error_dialog;
 
   FontViewModel *model;
   GtkSortListModel *sort_model;
@@ -133,7 +133,7 @@ install_button_refresh_appearance (FontViewWindow *self,
         gtk_button_set_label (self->install_button, _ ("Installing"));
         gtk_widget_set_sensitive (GTK_WIDGET (self->install_button), FALSE);
     } else {
-        gtk_button_set_label (self->install_button, _ ("Install"));
+        gtk_button_set_label (self->install_button, _ ("_Install"));
         gtk_widget_set_sensitive (GTK_WIDGET (self->install_button), TRUE);
         gtk_widget_add_css_class (GTK_WIDGET (self->install_button),
                                   "suggested-action");
@@ -554,11 +554,11 @@ font_install_finished (GObject *source_object,
   g_task_propagate_boolean (G_TASK (res), &err);
 
   if (err != NULL) {
-    install_button_refresh_appearance (self, err);
     font_view_window_show_error (self,
                                  _("Could Not Install Font"),
                                  err->message);
   }
+  install_button_refresh_appearance (self, err);
 
   g_clear_object (&self->cancellable);
 }
@@ -758,8 +758,11 @@ font_view_window_show_overview (FontViewWindow *self)
 }
 
 static void
-action_toggle_search_cb (FontViewWindow *self)
+action_toggle_search_cb (GtkWidget  *widget,
+                         const char *action_name,
+                         GVariant   *parameter)
 {
+  FontViewWindow *self = FONT_VIEW_WINDOW (widget);
 
  gtk_toggle_button_set_active (self->search_button,
                                !gtk_toggle_button_get_active (self->search_button));
@@ -805,9 +808,9 @@ font_view_window_show_error (FontViewWindow *self,
                              const char     *heading,
                              const char     *body)
 {
-  adw_message_dialog_set_heading (self->error_dialog, heading);
-  adw_message_dialog_set_body (self->error_dialog, heading);
-  gtk_window_present (GTK_WINDOW (self->error_dialog));
+  adw_alert_dialog_set_heading (self->error_dialog, heading);
+  adw_alert_dialog_set_body (self->error_dialog, heading);
+  adw_dialog_present (ADW_DIALOG (self->error_dialog), GTK_WIDGET (self));
 }
 
 static void
